==> copilot-24.7.2-sources.jar: com/vaadin/copilot/customcomponent/CustomComponentInstanceInfo.java <==
package com.vaadin.copilot.customcomponent;

import java.util.List;

/**
 * Contains information about custom component instance.
 */
public class CustomComponentInstanceInfo extends ComponentInfoForCustomComponentSupport {
    private CustomComponent.Type type;
    private String activeLevel;
    private final String javaClassName;
    private final List<CustomComponentAddMethodInfo> addMethodInfoList;
    private final String customComponentFilePath;

    public CustomComponentInstanceInfo(CustomComponent.Type type, String activeLevel,
            List<CustomComponentAddMethodInfo> addMethodInfoList, String javaClassName,
            String customComponentFilePath) {
        this.type = type;
        this.activeLevel = activeLevel;
        this.addMethodInfoList = List.copyOf(addMethodInfoList);
        this.javaClassName = javaClassName;
        this.customComponentFilePath = customComponentFilePath;
    }

    public CustomComponent.Type getType() {
        return type;
    }

    public void setType(CustomComponent.Type type) {
        this.type = type;
    }

    public String getActiveLevel() {
        return activeLevel;
    }

    public void setActiveLevel(String activeLevel) {
        this.activeLevel = activeLevel;
    }

    public List<CustomComponentAddMethodInfo> getAddMethodInfoList() {
        return addMethodInfoList;
    }

    public String getJavaClassName() {
        return javaClassName;
    }

    public String getCustomComponentFilePath() {
        return customComponentFilePath;
    }
}

==> copilot-25.1-20260113.105429-64-sources.jar: com/vaadin/copilot/customcomponent/CustomComponentInstanceInfo.java <==
package com.vaadin.copilot.customcomponent;

/**
 * Contains information about custom component instance.
 */
public class CustomComponentInstanceInfo extends ComponentInfoForCustomComponentSupport {
    private CustomComponent.Type type;
    private String activeLevel;
    private boolean defaultConstructorPresence;
    private final String javaClassName;
    private final String customComponentFilePath;
    private final boolean litTemplate;

    public CustomComponentInstanceInfo(CustomComponent.Type type, String activeLevel, String javaClassName,
            String customComponentFilePath, boolean litTemplate) {
        this.type = type;
        this.activeLevel = activeLevel;
        this.javaClassName = javaClassName;
        this.customComponentFilePath = customComponentFilePath;
        this.litTemplate = litTemplate;
    }

    public CustomComponent.Type getType() {
        return type;
    }

    public void setType(CustomComponent.Type type) {
        this.type = type;
    }

    public String getActiveLevel() {
        return activeLevel;
    }

    public void setActiveLevel(String activeLevel) {
        this.activeLevel = activeLevel;
    }

    public String getJavaClassName() {
        return javaClassName;
    }

    public String getCustomComponentFilePath() {
        return customComponentFilePath;
    }

    public boolean isLitTemplate() {
        return litTemplate;
    }

    public boolean isDefaultConstructorPresence() {
        return defaultConstructorPresence;
    }

    public void setDefaultConstructorPresence(boolean defaultConstructorPresence) {
        this.defaultConstructorPresence = defaultConstructorPresence;
    }
}
